public inbox for git-commits@fedoraproject.org
help / color / mirror / Atom feed
From: Yaakov Selkowitz <yselkowi@redhat.com>
To: git-commits@fedoraproject.org
Subject: [flatpaks/flatpak-runtime] f45: Update exclusions and renames for Fedora 45
Date: Fri, 11 Sep 2026 14:43:49 GMT	[thread overview]
Message-ID: <178913782942.1.3465355630525509827.flatpaks-flatpak-runtime-66e68e8c7c28@fedoraproject.org> (raw)

A new commit has been pushed.

Repo   : flatpaks/flatpak-runtime
Branch : f45
Commit : 66e68e8c7c28c347ddaac5b1d8a87df7bef8e7cf
Author : Yaakov Selkowitz <yselkowi@redhat.com>
Date   : 2026-09-11T10:38:42-04:00
Stats  : +29/-27 in 2 file(s)
URL    : https://src.fedoraproject.org/flatpaks/flatpak-runtime/c/66e68e8c7c28c347ddaac5b1d8a87df7bef8e7cf?branch=f45

Log:
Update exclusions and renames for Fedora 45

---
diff --git a/package-notes.txt b/package-notes.txt
index 6d67ace..cf83046 100644
--- a/package-notes.txt
+++ b/package-notes.txt
@@ -14,6 +14,7 @@
 #
 adwaita-cursor-theme: W: part of runtime, but not bin/libs
 adwaita-icon-theme: W: part of runtime, but not bin/libs
+appstream: E: for flatseal
 audit-libs: Fedora builds things this way
 authselect: EB: needed for /etc/nsswitch.conf
 avahi-glib: EB: include this as well as we already have avahi-libs

diff --git a/tools/resolve-files.py b/tools/resolve-files.py
index b8fbc33..f3a2c77 100755
--- a/tools/resolve-files.py
+++ b/tools/resolve-files.py
@@ -72,8 +72,8 @@ bin_ignore = [
     'hw-support', 'nss', 'pwdecrypt', 'shlibsign', 'signtool', 'symkeyutil', 'validation',
 
     # Versioned python3 binaries
-    'pydoc3.13', 'python3.13', 'python3.13-config', 'python3.13m',  'python3.13m-config', '2to3-3.13',
-    'easy_install-3.13', 'pip3.13', 'pyvenv-3.13',
+    'pydoc3.14', 'python3.14', 'python3.14-config', 'python3.14m',  'python3.14m-config', '2to3-3.14',
+    'easy_install-3.14', 'pip3.14', 'pyvenv-3.14',
 
     # nettle utilities not currently packaged in fedora
     # (https://src.fedoraproject.org/rpms/nettle/c/2ec204e2de17006b566c9ff7d90ec65ca1680ed5?branch=master)
@@ -159,7 +159,7 @@ lib_ignore = [
     'libapparmor.so', 'libapparmor.so.1',
 
     # binutils internal libraries
-    'libbfd-2.46.so', 'libopcodes-2.46.so', 'libgprofng.so', 'libgprofng.so.0',
+    'libbfd-2.46.1.so', 'libopcodes-2.46.1.so', 'libgprofng.so', 'libgprofng.so.0',
 
     # Trimmed from gettext(-devel)
     'libgettextlib.so', 'libgettextsrc.so', 'libtextstyle.so', 'libtextstyle.so.0',
@@ -171,9 +171,9 @@ lib_ignore = [
     'libc_malloc_debug.so', 'libssp.so.0',
 
     # glslang is built as static libraries only
-    'libHLSL.so.15', 'libHLSL.so', 'libSPIRV.so.15', 'libSPIRV.so',
-    'libSPVRemapper.so.15', 'libSPVRemapper.so', 'libglslang.so.15', 'libglslang.so',
-    'libglslang-default-resource-limits.so.15', 'libglslang-default-resource-limits.so',
+    'libHLSL.so.16', 'libHLSL.so', 'libSPIRV.so.16', 'libSPIRV.so',
+    'libSPVRemapper.so.16', 'libSPVRemapper.so', 'libglslang.so.16', 'libglslang.so',
+    'libglslang-default-resource-limits.so.16', 'libglslang-default-resource-limits.so',
 
     # Only used by man-db in Fedora
     'libpipeline.so', 'libpipeline.so.1',
@@ -188,15 +188,19 @@ lib_rename = {
     # Newer or older in Fedora
     'libabigail.so.8': 'libabigail.so.9',
     'libassuan.so.9': 'libassuan.so.0',
+    'libcrypto.so.3': 'libcrypto.so.4',
     'libFLAC++.so.10': 'libFLAC++.so.11',
     'libFLAC.so.12': 'libFLAC.so.14',
-#    'libgettextlib-0.26.so': 'libgettextlib-0.25.1.so',
-#    'libgettextsrc-0.26.so': 'libgettextsrc-0.25.1.so',
+    'libgettextlib-0.26.so': 'libgettextlib-1.0.so',
+    'libgettextsrc-0.26.so': 'libgettextsrc-1.0.so',
     'libmanette-1.so.0': 'libmanette-0.2.so.0',
     'libnsl.so.1': 'libnsl.so.3',
-    'libpython3.13.so.1.0': 'libpython3.14.so.1.0',
-    'libpython3.13.so': 'libpython3.14.so',
+    'libp11.so.3': 'libp11.so.4',
+    'libpkgconf.so.8': 'libpkgconf.so.7',
+    'libpython3.14.so.1.0': 'libpython3.15.so.1.0',
+    'libpython3.14.so': 'libpython3.15.so',
     'libsframe.so.2': 'libsframe.so.3',
+    'libssl.so.3': 'libssl.so.4',
     'libtcl8.6.so': 'libtcl9.0.so',
     'libtk8.6.so': 'libtcl9tk9.0.so',
     'libtheora.so.1': 'libtheora.so.0',
@@ -204,7 +208,7 @@ lib_rename = {
     'libtheoraenc.so.2': 'libtheoraenc.so.1',
     'libvala-0.58.so.0': 'libvala-0.56.so.0',
     'libverto.so.0': 'libverto.so.1',
-    'libvpx.so.11': 'libvpx.so.9',
+    'libvpx.so.11': 'libvpx.so.12',
     'libwget.so.3': 'libwget.so.4',
     'libxml2.so.16': 'libxml2.so.2',
     'libZXing.so.1': 'libZXing.so.3',
@@ -224,11 +228,6 @@ lib_rename = {
     # ncurses is built with a single tinfo library for both narrow and wide
     'libtinfow.so': 'libtinfo.so',
     'libtinfow.so.6': 'libtinfo.so.6',
-
-    # named differently when built with autotools vs cmake
-    'libSDL2_image-2.0.so': 'libSDL2_image.so',
-    'libSDL2_mixer-2.0.so': 'libSDL2_mixer.so',
-    'libSDL2_net-2.0.so': 'libSDL2_net.so',
 }
 rename.update({'/usr/lib64/' + k: '/usr/lib64/' + v for k, v in lib_rename.items()})
 
@@ -245,7 +244,7 @@ for old in ['libasm-0.193.so', 'libdw-0.193.so', 'libelf-0.193.so', 'libdebuginf
 # Fedora may have newer icu
 for old in ['libicudata.so.77', 'libicui18n.so.77', 'libicuio.so.77', 'libicutest.so.77',
             'libicutu.so.77', 'libicuuc.so.77']:
-    rename['/usr/lib64/' + old] = '/usr/lib64/' + old.replace('so.77', 'so.77')
+    rename['/usr/lib64/' + old] = '/usr/lib64/' + old.replace('so.77', 'so.78')
 
 include_rename = {
     'asoundlib.h': 'alsa/asoundlib.h',
@@ -307,8 +306,8 @@ pc_rename = {
     'libvala-0.58.pc': 'libvala-0.56.pc',
     'manette-1.pc': 'manette-0.2.pc',
 #    'mozjs-140.pc': 'mozjs-140.pc',
-    'python-3.13.pc': 'python-3.14.pc',
-    'python-3.13-embed.pc': 'python-3.14-embed.pc',
+    'python-3.14.pc': 'python-3.15.pc',
+    'python-3.14-embed.pc': 'python-3.15-embed.pc',
     'vapigen-0.58.pc': 'vapigen-0.56.pc',
 }
 rename.update({'/usr/lib64/pkgconfig/' + k: '/usr/lib64/pkgconfig/' + v for k, v in pc_rename.items()})
@@ -372,15 +371,16 @@ ignore_patterns = [
     r'/usr/lib64/python[\d.]+/site-packages/Cython/(Plex/Timing|Plex/Traditional)\.py',
     r'/usr/lib64/python[\d.]+/site-packages/Cython/Utility/Capsule\.c',
 
     # Removed or renamed in Python 3.14
     r'/usr/lib64/python[\d.]+/_compression.py',
     r'/usr/lib64/python[\d.]+/_pyrepl/.*curses.py',
     r'/usr/lib64/python[\d.]+/encodings/.*',
     r'/usr/lib64/python[\d.]+/lib-dynload/_.*',
     r'/usr/lib64/python[\d.]+/pathlib/_.*',
-    r'/usr/lib64/python[\d.]+/site-packages/pkg_resources/tests/.*',
+    r'/usr/lib64/python[\d.]+/site-packages/pkg_resources/.*',
     r'/usr/lib64/python[\d.]+/site-packages/setuptools/_distutils/compilers/C/tests/.*',
     r'/usr/lib64/python[\d.]+/site-packages/setuptools/_distutils/tests/.*',
+    r'/usr/lib64/python[\d.]+/site-packages/setuptools/command/launcher.manifest.xml',
     r'/usr/lib64/python[\d.]+/site-packages/setuptools/tests/.*',
     r'/usr/lib64/python[\d.]+/site-packages/sitecustomize.py',
 
@@ -444,7 +444,7 @@ rename_patterns = [
 #    (r'^/usr/include/mozjs-140/(.*)', r'/usr/include/mozjs-140/\1'),
     (r'^/usr/include/nss/(.*)', r'/usr/include/nss3/\1'),
     (r'^/usr/include/(proxy.h)', r'/usr/include/libproxy/\1'),
-    (r'^/usr/include/python3.13/(.*)', r'/usr/include/python3.14/\1'),
+    (r'^/usr/include/python3.14/(.*)', r'/usr/include/python3.15/\1'),
     (r'^/usr/include/ruby-[\d\.]*/ruby/(.*)', r'/usr/include/ruby/\1'),
     (r'^/usr/include/ruby-[\d\.]*/x86_64-linux/ruby/(.*)', r'/usr/include/ruby/\1'),
     (r'^/usr/include/ruby-[\d\.]*/(.*)', r'/usr/include/ruby/\1'),
@@ -465,11 +465,11 @@ rename_patterns = [
     (r'^/usr/lib64/perl5/[\d.]+/(.*)', r'/usr/lib64/perl5/\1'),
     (r'^/usr/lib64/pkgconfig/(.*proto.pc)', r'/usr/share/pkgconfig/\1'),
     (r'^/usr/lib64/pkgconfig/ruby-[\d\.]*.pc', r'/usr/lib64/pkgconfig/ruby.pc'),
-    (r'^/usr/lib64/python3.13/(pathlib|sysconfig).py', r'/usr/lib64/python3.14/\1/__init__.py'),
-    (r'^/usr/lib64/python3.13/(site-packages/_dbus.*).cpython-313-.*', r'/usr/lib64/python3.14/\1.so'),
-    (r'^/usr/lib64/python3.13/config-3.13-(.*)', r'/usr/lib64/python3.14/config-3.14-\1'),
-    (r'^/usr/lib64/python3.13/(.*).cpython-313-(.*)', r'/usr/lib64/python3.14/\1.cpython-314-\2'),
-    (r'^/usr/lib64/python3.13/(.*)', r'/usr/lib64/python3.14/\1'),
+    (r'^/usr/lib64/python3.14/(pathlib|sysconfig).py', r'/usr/lib64/python3.15/\1/__init__.py'),
+    (r'^/usr/lib64/python3.14/(site-packages/_dbus.*).cpython-314-.*', r'/usr/lib64/python3.15/\1.so'),
+    (r'^/usr/lib64/python3.14/config-3.14-(.*)', r'/usr/lib64/python3.15/config-3.15-\1'),
+    (r'^/usr/lib64/python3.14/(.*).cpython-314-(.*)', r'/usr/lib64/python3.15/\1.cpython-315-\2'),
+    (r'^/usr/lib64/python3.14/(.*)', r'/usr/lib64/python3.15/\1'),
     (r'^/usr/lib64/(v4l[12].*.so)', r'/usr/lib64/libv4l/\1'),
     (r'^/usr/libexec/(ssh-.*)', r'/usr/libexec/openssh/\1'),
     (r'^/usr/libexec/gcc/x86_64-unknown-linux-gnu/[\d\.]*/(.*)', r'/usr/libexec/gcc/x86_64-redhat-linux/16/\1'),
@@ -657,6 +657,7 @@ platform_package_ignore_patterns = [
     "^appstream-compose",
     "^blueprint-compiler",
     "^libappstream-glib-builder$", # may not need in the sdk either
+    "^fftw$",
     "^gcc-gdb-plugin$",  # pulls in gcc
     '^gperf$',
     "^gtk-doc$",
@@ -372,15 +371,16 @@ ignore_patterns = [
     r'/usr/lib64/python[\d.]+/site-packages/Cython/Utility/Capsule\.c',
 
-    # Removed or renamed in Python 3.14
+    # Removed or renamed in Python 3.15, setuptools 82
     r'/usr/lib64/python[\d.]+/_compression.py',
     r'/usr/lib64/python[\d.]+/_pyrepl/.*curses.py',

                 reply	other threads:[~2026-09-11 14:43 UTC|newest]

Thread overview: [no followups] expand[flat|nested]  mbox.gz  Atom feed

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=178913782942.1.3465355630525509827.flatpaks-flatpak-runtime-66e68e8c7c28@fedoraproject.org \
    --to=yselkowi@redhat.com \
    --cc=git-commits@fedoraproject.org \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox